import requests
import time

def html_get(url: str) -> str:
    Header = {
        "User-Agent": (
            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
            "AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/114.0.0.0 Safari/537.36"
        ),
        "Accept-Language": "en-US,en;q=0.9",
        "Referer": "https://www.google.com/"
    }
    response = requests.get(url, headers=Header)
    response.raise_for_status()
    time.sleep(0.2)
    return response.text


import sys
import os

sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))

from scholr import get_scholar_profile, get_publication_details

user_id = "your_user_id"

def test_get_scholar_profile():
    profile = get_scholar_profile(user_id)

    print("Profile basic information:")
    print(profile)

    return profile

def test_get_publication_details(publication_url):
    publication = get_publication_details(publication_url)
    print("Publication details:")
    print(publication)

if __name__ == "__main__":
    profile = test_get_scholar_profile()

    for pub in profile.get("publications", []):
        test_get_publication_details(pub.get("url"))



from bs4 import BeautifulSoup

def parse_scholar_profile(html: str) -> dict:
    soup = BeautifulSoup(html, 'html.parser')
    profile_info = {}

     # Extracting the name
    name_tag = soup.find('div', id='gsc_prf_in')
    if name_tag:
        profile_info['name'] = name_tag.text.strip()
    else:
        print("Profile not found")
        exit(1)

    # Extracting the affiliation
    affiliation_tag = soup.find('div', class_='gsc_prf_il')
    if affiliation_tag:
        profile_info['affiliation'] = affiliation_tag.text.strip()

    # Extracting the research interests
    interests = [a.text for a in soup.select('#gsc_prf_int a')]
    profile_info['interests'] = interests

    # Extracting the profile photo URL
    photo_tag = soup.find('img', id='gsc_prf_pup-img')
    if photo_tag and photo_tag.get('src'):
        profile_info['photo_url'] = photo_tag['src']

    # Extracting the statistics
    stats = soup.select('table#gsc_rsb_st td.gsc_rsb_std')
    if len(stats) >= 6:
        profile_info['citations_all'] = stats[0].text
        profile_info['citations_since_2019'] = stats[1].text
        profile_info['h_index_all'] = stats[2].text
        profile_info['h_index_since_2019'] = stats[3].text
        profile_info['i10_index_all'] = stats[4].text
        profile_info['i10_index_since_2019'] = stats[5].text

    # Extracting the publications
    publications = []
    rows = soup.select('tr.gsc_a_tr')
    for row in rows:
        title_tag = row.select_one('.gsc_a_at')
        title = title_tag.text if title_tag else ""
        url = "https://scholar.google.com" + title_tag['href'] if title_tag and title_tag.get('href') else None

        publications.append({
            "title": title,
            "url": url,
        })

    profile_info["publications"] = publications

    return profile_info

def parse_publication_details(html: str) -> dict:
    soup = BeautifulSoup(html, 'html.parser')
    publication_info = {}

    # Extracting the title
    title_tag = soup.find('a', class_='gsc_oci_title_link')
    publication_info['title'] = title_tag.text.strip() if title_tag else "No Title"

    rows = soup.select('#gsc_oci_table .gs_scl')
    if len(rows) >= 9:
        # Extracting the date
        publication_info['date'] = rows[1].select_one('.gsc_oci_value').text.strip()
        
        # Extracting the citations
        citations_tag = rows[8].select_one('.gsc_oci_value a')
        publication_info['citations'] = citations_tag.text.strip() if citations_tag else "0"

    publication_info['url'] = title_tag['href'] if title_tag else None

    return publication_info


from setuptools import setup, find_packages

setup(
    name='scholr',
    version='0.2.2',
    author='Anas AlMutary',
    author_email='me@ianas.me',
    description='A lightweight scraper for Google Scholar',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/An4s0/Scholr',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
    ],
    python_requires='>=3.7',
    install_requires=[
        'beautifulsoup4',
        'requests',
    ],
)


from .utils import html_get
from .parser import parse_scholar_profile, parse_publication_details

GOOGLE_SCHOLAR_URL = "https://scholar.google.com/citations?user="

def get_scholar_profile(user_id: str) -> dict:
    """
    Fetch the Google Scholar profile information for a given user ID.

    :param user_id: The user ID of the Google Scholar profile.
    :return: A dictionary containing the user's profile information.
    """
    profile_info = None
    all_pubs = []
    start = 0 

    while True:
        url = f"{GOOGLE_SCHOLAR_URL}{user_id}&cstart={start}&pagesize=100&hl=en&view_op=list_works"
        html = html_get(url)
        if not html or "Please show you're not a robot" in html:
            print("Blocked by Google Scholar or empty page")
            break

        page_info = parse_scholar_profile(html)

        if profile_info is None:
            profile_info = {k: v for k, v in page_info.items() if k != "publications"}

        pubs = page_info.get("publications", [])
        if len(pubs) == 1:
            break
        all_pubs.extend(pubs)
        start += 100

    profile_info["publications"] = all_pubs

    return profile_info

def get_publication_details(publication_url: str) -> dict:
    """
    Fetch the details of a specific publication from Google Scholar.

    :param publication_url: The URL of the publication on Google Scholar.
    :return: A dictionary containing the publication details.
    """
    html = html_get(publication_url)
    if not html or "Please show you're not a robot" in html:
        print("Blocked by Google Scholar or empty page")
        return {}

    publication_details = parse_publication_details(html)

    return publication_details